@@ -36,7 +36,7 @@ echo "Installing openfl"
 
 pip install openfl   I
 
-echo "openfl folder is downloaded in \e[1;32m\home\intel\<username>\e[0m"
+echo -e "\e[1;34mOPENFL folder is downloaded in \home\intel\<username>\e[0m\n"
 
 #Check RI is installed sucessfully
 
